@@ -83,7 +83,7 @@ class TestCaching:
 
     def test_altering_series_clears_parent_cache(self):
         # GH #33675
-        df = pd.DataFrame([[1, 2], [3, 4]], index=["a", "b"], columns=["A", "B"])
+        df = DataFrame([[1, 2], [3, 4]], index=["a", "b"], columns=["A", "B"])
         ser = df["A"]
 
         assert "A" in df._item_cache
@@ -121,17 +121,18 @@ class TestChaining:
         tm.assert_frame_equal(df, DataFrame({"response": mdata, "response1": data}))
 
         # GH 6056
-        expected = DataFrame(dict(A=[np.nan, "bar", "bah", "foo", "bar"]))
-        df = DataFrame(dict(A=np.array(["foo", "bar", "bah", "foo", "bar"])))
+        expected = DataFrame({"A": [np.nan, "bar", "bah", "foo", "bar"]})
+        df = DataFrame({"A": np.array(["foo", "bar", "bah", "foo", "bar"])})
         df["A"].iloc[0] = np.nan
         result = df.head()
         tm.assert_frame_equal(result, expected)
 
-        df = DataFrame(dict(A=np.array(["foo", "bar", "bah", "foo", "bar"])))
+        df = DataFrame({"A": np.array(["foo", "bar", "bah", "foo", "bar"])})
         df.A.iloc[0] = np.nan
         result = df.head()
         tm.assert_frame_equal(result, expected)
 
+    @pytest.mark.arm_slow
     def test_detect_chained_assignment(self):
 
         pd.set_option("chained_assignment", "raise")
@@ -154,10 +155,11 @@ class TestChaining:
         )
         assert df._is_copy is None
 
-        with pytest.raises(com.SettingWithCopyError):
+        msg = "A value is trying to be set on a copy of a slice from a DataFrame"
+        with pytest.raises(com.SettingWithCopyError, match=msg):
             df["A"][0] = -5
 
-        with pytest.raises(com.SettingWithCopyError):
+        with pytest.raises(com.SettingWithCopyError, match=msg):
             df["A"][1] = np.nan
 
         assert df["A"]._is_copy is None
@@ -170,7 +172,7 @@ class TestChaining:
             }
         )
 
-        with pytest.raises(com.SettingWithCopyError):
+        with pytest.raises(com.SettingWithCopyError, match=msg):
             df.loc[0]["A"] = -5
 
         # Doc example
@@ -182,17 +184,17 @@ class TestChaining:
         )
         assert df._is_copy is None
 
-        with pytest.raises(com.SettingWithCopyError):
+        with pytest.raises(com.SettingWithCopyError, match=msg):
             indexer = df.a.str.startswith("o")
             df[indexer]["c"] = 42
 
         expected = DataFrame({"A": [111, "bbb", "ccc"], "B": [1, 2, 3]})
         df = DataFrame({"A": ["aaa", "bbb", "ccc"], "B": [1, 2, 3]})
 
-        with pytest.raises(com.SettingWithCopyError):
+        with pytest.raises(com.SettingWithCopyError, match=msg):
             df["A"][0] = 111
 
-        with pytest.raises(com.SettingWithCopyError):
+        with pytest.raises(com.SettingWithCopyError, match=msg):
             df.loc[0]["A"] = 111
 
         df.loc[0, "A"] = 111
@@ -292,26 +294,26 @@ class TestChaining:
         df = DataFrame(np.arange(0, 9), columns=["count"])
         df["group"] = "b"
 
-        with pytest.raises(com.SettingWithCopyError):
+        with pytest.raises(com.SettingWithCopyError, match=msg):
             df.iloc[0:5]["group"] = "a"
 
         # Mixed type setting but same dtype & changing dtype
         df = DataFrame(
-            dict(
-                A=date_range("20130101", periods=5),
-                B=np.random.randn(5),
-                C=np.arange(5, dtype="int64"),
-                D=list("abcde"),
-            )
+            {
+                "A": date_range("20130101", periods=5),
+                "B": np.random.randn(5),
+                "C": np.arange(5, dtype="int64"),
+                "D": ["a", "b", "c", "d", "e"],
+            }
         )
 
-        with pytest.raises(com.SettingWithCopyError):
+        with pytest.raises(com.SettingWithCopyError, match=msg):
             df.loc[2]["D"] = "foo"
 
-        with pytest.raises(com.SettingWithCopyError):
+        with pytest.raises(com.SettingWithCopyError, match=msg):
             df.loc[2]["C"] = "foo"
 
-        with pytest.raises(com.SettingWithCopyError):
+        with pytest.raises(com.SettingWithCopyError, match=msg):
             df["C"][2] = "foo"
 
     def test_setting_with_copy_bug(self):
@@ -334,24 +336,26 @@ class TestChaining:
         # this should not raise
         df2["y"] = ["g", "h", "i"]
 
-    def test_detect_chained_assignment_warnings(self):
+    def test_detect_chained_assignment_warnings_errors(self):
+        df = DataFrame({"A": ["aaa", "bbb", "ccc"], "B": [1, 2, 3]})
         with option_context("chained_assignment", "warn"):
-            df = DataFrame({"A": ["aaa", "bbb", "ccc"], "B": [1, 2, 3]})
-
             with tm.assert_produces_warning(com.SettingWithCopyWarning):
                 df.loc[0]["A"] = 111
 
+        msg = "A value is trying to be set on a copy of a slice from a DataFrame"
+        with option_context("chained_assignment", "raise"):
+            with pytest.raises(com.SettingWithCopyError, match=msg):
+                df.loc[0]["A"] = 111
+
     def test_detect_chained_assignment_warnings_filter_and_dupe_cols(self):
         # xref gh-13017.
         with option_context("chained_assignment", "warn"):
-            df = pd.DataFrame(
-                [[1, 2, 3], [4, 5, 6], [7, 8, -9]], columns=["a", "a", "c"]
-            )
+            df = DataFrame([[1, 2, 3], [4, 5, 6], [7, 8, -9]], columns=["a", "a", "c"])
 
             with tm.assert_produces_warning(com.SettingWithCopyWarning):
                 df.c.loc[df.c > 0] = None
 
-            expected = pd.DataFrame(
+            expected = DataFrame(
                 [[1, 2, 3], [4, 5, 6], [7, 8, -9]], columns=["a", "a", "c"]
             )
             tm.assert_frame_equal(df, expected)
